@@ -24,6 +24,7 @@ from pydoll.constants import (
     DownloadBehavior,
     NetworkErrorReason,
     PermissionType,
+    RequestMethod,
     ResourceType,
 )
 from pydoll.exceptions import BrowserNotRunning, FailedToStartBrowser, NoValidTabFound
@@ -215,10 +216,31 @@ class Browser(ABC):  # noqa: PLR0904
 
         Targets include pages, service workers, shared workers, and browser process.
         Useful for debugging and managing multiple tabs.
+
+        Returns:
+            List of TargetInfo objects.
         """
         response: GetTargetsResponse = await self._execute_command(TargetCommands.get_targets())
         return response['result']['targetInfos']
 
+    async def get_opened_tabs(self) -> list[Tab]:
+        """
+        Get all opened tabs that are not extensions and have the type 'page'
+
+        Returns:
+            List of Tab instances. The last tab is the most recent one.
+        """
+        targets = await self.get_targets()
+        valid_tab_targets = [
+            target
+            for target in targets
+            if target['type'] == 'page' and 'extension' not in target['url']
+        ]
+        return [
+            Tab(self, self._connection_port, target['targetId'])
+            for target in reversed(valid_tab_targets)
+        ]
+
     async def set_download_path(self, path: str, browser_context_id: Optional[str] = None):
         """Set download directory path (convenience method for set_download_behavior)."""
         return await self._execute_command(
@@ -404,11 +426,28 @@ class Browser(ABC):  # noqa: PLR0904
         """Disable runtime events."""
         return await self._connection_handler.execute_command(RuntimeCommands.disable())
 
-    async def continue_request(self, request_id: str):
+    async def continue_request(  # noqa: PLR0913, PLR0917
+        self,
+        request_id: str,
+        url: Optional[str] = None,
+        method: Optional[RequestMethod] = None,
+        post_data: Optional[str] = None,
+        headers: Optional[list[HeaderEntry]] = None,
+        intercept_response: Optional[bool] = None,
+    ):
         """
         Continue paused request without modifications.
         """
-        return await self._execute_command(FetchCommands.continue_request(request_id))
+        return await self._execute_command(
+            FetchCommands.continue_request(
+                request_id=request_id,
+                url=url,
+                method=method,
+                post_data=post_data,
+                headers=headers,
+                intercept_response=intercept_response,
+            )
+        )
 
     async def fail_request(self, request_id: str, error_reason: NetworkErrorReason):
         """Fail request with error code."""
@@ -418,16 +457,18 @@ class Browser(ABC):  # noqa: PLR0904
         self,
         request_id: str,
         response_code: int,
-        response_headers: list[HeaderEntry],
-        response_body: dict[Any, Any],
+        response_headers: Optional[list[HeaderEntry]] = None,
+        body: Optional[str] = None,
+        response_phrase: Optional[str] = None,
     ):
         """Fulfill request with response data."""
         return await self._execute_command(
             FetchCommands.fulfill_request(
-                request_id,
-                response_code,
-                response_headers,
-                response_body,
+                request_id=request_id,
+                response_code=response_code,
+                response_headers=response_headers,
+                body=body,
+                response_phrase=response_phrase,
             )
         )
 
